---
title: llarp/rpc/rpc_server.hpp

---

# llarp/rpc/rpc_server.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::rpc](Namespaces/namespacellarp_1_1rpc.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::rpc::MessageHandler](Classes/structllarp_1_1rpc_1_1MessageHandler.md)**  |

## Functions

|                | Name           |
| -------------- | -------------- |
| | **[MessageHandler](Files/rpc__server_8hpp.md#function-messagehandler)**(AbstractRouter & _r) |
| | **[~MessageHandler](Files/rpc__server_8hpp.md#function-~messagehandler)**() =default |
| void | **[SetMessage](Files/rpc__server_8hpp.md#function-setmessage)**(Message & _msg) |
| void | **[ClearMessage](Files/rpc__server_8hpp.md#function-clearmessage)**() |
| void | **[SendImmediateResponse](Files/rpc__server_8hpp.md#function-sendimmediateresponse)**(oxenmq::Message & msg, auto content) |
| void | **[SendDelayedResponse](Files/rpc__server_8hpp.md#function-senddelayedresponse)**(oxenmq::Message & msg, auto content) |
| void | **[SendImmediateError](Files/rpc__server_8hpp.md#function-sendimmediateerror)**(oxenmq::Message & msg, auto content) |
| template <typename Result_t \> <br>std::string | **[CreateJSONResponse](Files/rpc__server_8hpp.md#function-createjsonresponse)**(Result_t result) |
| std::string | **[CreateJSONError](Files/rpc__server_8hpp.md#function-createjsonerror)**(std::string_view msg) |

## Attributes

|                | Name           |
| -------------- | -------------- |
| AbstractRouter &const | **[m_Router](Files/rpc__server_8hpp.md#variable-m-router)**  |


## Functions Documentation

### function MessageHandler

```cpp
explicit MessageHandler(
    AbstractRouter & _r
)
```


### function ~MessageHandler

```cpp
~MessageHandler() =default
```


### function SetMessage

```cpp
void SetMessage(
    Message & _msg
)
```


### function ClearMessage

```cpp
void ClearMessage()
```


### function SendImmediateResponse

```cpp
void SendImmediateResponse(
    oxenmq::Message & msg,
    auto content
)
```


### function SendDelayedResponse

```cpp
void SendDelayedResponse(
    oxenmq::Message & msg,
    auto content
)
```


### function SendImmediateError

```cpp
void SendImmediateError(
    oxenmq::Message & msg,
    auto content
)
```


### function CreateJSONResponse

```cpp
template <typename Result_t >
std::string CreateJSONResponse(
    Result_t result
)
```


### function CreateJSONError

```cpp
std::string CreateJSONError(
    std::string_view msg
)
```



## Attributes Documentation

### variable m_Router

```cpp
AbstractRouter &const m_Router;
```



## Source code

```cpp
#pragma once

#include <string_view>
#include <llarp/config/config.hpp>
#include <oxenmq/oxenmq.h>
#include <oxenmq/address.h>
#include <oxen/log/omq_logger.hpp>


namespace llarp
{
  struct AbstractRouter;
} 


namespace llarp::rpc
{
  using LMQ_ptr = std::shared_ptr<oxenmq::OxenMQ>;


  struct MessageHandler
  {
    explicit MessageHandler(AbstractRouter&);

    explicit MessageHandler(AbstractRouter& _r) : m_Router(_r) {};
    
    ~MessageHandler() = default;

    void
    SetMessage(Message& _msg) { msg = _msg; }

    void
    ClearMessage() { msg = nullptr; }

    void 
    SendImmediateResponse(oxenmq::Message& msg, auto content);
    void 
    SendDelayedResponse(oxenmq::Message& msg, auto content);

    void
    SendImmediateError(oxenmq::Message& msg, auto content);

    template <typename Result_t>
    std::string
    CreateJSONResponse(Result_t result) 
        { return nlohmann::json{{"error", nullptr},{"result"}, result}.dump(); }

    std::string
    CreateJSONError(std::string_view msg) 
        { return nlohmann::json{{"error", msg}}.dump(); }

    AbstractRouter& const m_Router;
  }

  struct RPCServer
  {
    explicit RPCServer(LMQ_ptr, AbstractRouter&);

    ~RPCServer() = default;

    void
    AddCategories();

  private:

    LMQ_ptr m_LMQ;
    AbstractRouter& const m_Router;
    oxen::log::PubsubLogger log_subs;

  };

}  // namespace llarp::rpc
```


-------------------------------

Updated on 2023-01-11 at 21:27:33 +0000
